#ifndef __SENSOR8_H__
#define __SENSOR8_H__

extern const char temp_in[8], digital_in[8], analog_in[8],
	set_hi[8], set_lo[8];

#define CMD_TEMP_IN(N)		temp_in[N]
#define CMD_DIGITAL_IN(N)	digital_in[N]
#define CMD_VIN(N)		analog_in[N]
#define CMD_SET_HI(N)		set_hi[N]
#define CMD_SET1		CMD_SET_HI
#define CMD_SET_LO(N)		set_lo[N]
#define CMD_SET0		CMD_SET_LO

#define BSWAP16(X)		((((X)>>8)|((X)<<8)) & 0xffff)
#define BIN16_TO_TEMP(X)	((X)/16.0f)
#define BIN16_TO_F(X)		((((X)*9)/80.0f)+32.0)
#define BIN16_TO_VOLT(X)	((BSWAP16(X) * 5)/1024.0)

typedef signed short temp_t;

enum
{
	// Reads temperature from a DS18B20 attached to the pin
	CMD_0_TEMP	='9',	CMD_1_TEMP	='0',
	CMD_2_TEMP	='-',	CMD_3_TEMP	='=',
	CMD_4_TEMP	='O',	CMD_5_TEMP	='P',
	CMD_6_TEMP	='[',	CMD_7_TEMP	=']',

	// Reads digital 1 or 0 from the pin
	CMD_0_DIN	='A',	CMD_1_DIN	='S',
	CMD_2_DIN	='D',	CMD_3_DIN	='F',
	CMD_4_DIN	='G',	CMD_5_DIN	='H',
	CMD_6_DIN	='J',	CMD_7_DIN	='K',

	// Reads analog voltage from the pin
	CMD_0_AIN	='Z',	CMD_1_AIN	='X',
	CMD_2_AIN	='C',	CMD_3_AIN	='V',
	CMD_4_AIN	='B',	CMD_5_AIN	='N',
	CMD_6_AIN	='M',	CMD_7_AIN	=',',

	// Sets the pin high (5V)
	CMD_0_HI	='1',	CMD_1_HI	='2',
	CMD_2_HI	='3',	CMD_3_HI	='4',
	CMD_4_HI	='5',	CMD_5_HI	='6',
	CMD_6_HI	='7',	CMD_7_HI	='8',

	// Sets the pin low
	CMD_0_LO	='Q',	CMD_1_LO	='W',
	CMD_2_LO	='E',	CMD_3_LO	='R',
	CMD_4_LO	='T',	CMD_5_LO	='Y',
	CMD_6_LO	='U',	CMD_7_LO	='I',


	// Tells it to report all data human-readable
	CMD_SET_ASCII		=0x60,
	// Tells it to report all data as binary bytes
	// Temperatures get reported as per raw 18B20
	CMD_SET_BINARY		=0x5c,
	// These only matter in ASCII mode
	CMD_SET_FAHRENHEIT	=0x4c,
	CMD_SET_CELSIUS		=0x3b,
	// Asks the USB device to send a REPLY_PING back to us
	CMD_PING		=0x27,
	REPLY_PING		=0x51,
	// If you get this temperature, reread
	TEMP_ERROR		=0xffff,
	TEMP_RESET		=0x0550
};

// Reads a 16-bit temperature from pin 'sensor'.
// Divide by 16.0f to get degrees C.
temp_t get_temp(int fd, int sensor);
unsigned short get_volt(int fd, int sensor);

int read_n(int fd, void *buf, int n);
int write_n(int fd, const void *buf, int n);

#endif/*__SENSOR8_H__*/
